/**
 *
 * This file is part of Tulip (www.tulip-software.org)
 *
 * Authors: David Auber and the Tulip development Team
 * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
 *
 * Tulip is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *
 * Tulip is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 */
#ifndef _Tulip_TEXTEDITDIALOG_H
#define _Tulip_TEXTEDITDIALOG_H

#include <tulip/tulipconf.h>

#include <QtGui/QDialog>

#include "tulip/TextEditDialogData.h"

namespace tlp {

class TLP_QT_SCOPE TextEditDialog : public QDialog,public Ui::TextEditDialogData {

  Q_OBJECT

public :

  TextEditDialog(const QString &text,QWidget *parent=NULL):QDialog(parent) {
    setupUi(this);
    // don't break focus chain
    textEdit->setTabChangesFocus(true);
    textEdit->setText(text);
  }

  QString getText() {
    return textEdit->toPlainText();
  }

};

}

#endif






